@@ -367,7 +367,7 @@ UnityDialogScreen::donePaint()
       continue;
     }
 
-    it++;
+    ++it;
   }
 }
 
@@ -420,12 +420,8 @@ UnityDialogWindow::glAddGeometry(const GLTexture::MatrixList& matrices,
 /* Collect textures */
 void
 UnityDialogWindow::glDrawTexture(GLTexture*          texture,
-#ifdef USE_GLES
                                  const GLMatrix            &transform,
                                  const GLWindowPaintAttrib &attrib,
-#else
-                                 GLFragment::Attrib& fa,
-#endif
                                  unsigned int       mask)
 {
   unity::PaintInfoCollector::Active ()->processTexture (texture);
@@ -448,16 +444,12 @@ unity::GeometryCollection::status ()
 	  collectedMinVertices.size () == collectedMatrixLists.size ());
 }
 
-void
+bool
 unity::GeometryCollection::addGeometryForWindow (CompWindow *w, const CompRegion &paintRegion)
 {
   /* We can reset the window geometry since it will be
    * re-added later */
-#ifdef USE_GLES
   GLWindow::get (w)->vertexBuffer()->begin();
-#else
-  GLWindow::get (w)->geometry().reset();
-#endif
 
   for (unsigned int i = 0; i < collectedMatrixLists.size (); i++)
   {
@@ -472,9 +464,7 @@ unity::GeometryCollection::addGeometryForWindow (CompWindow *w, const CompRegion
     GLWindow::get (w)->glAddGeometry(matl, reg, paintRegion, min, max);
   }
 
-#ifdef USE_GLES
-  GLWindow::get (w)->vertexBuffer()->end();
-#endif
+  return GLWindow::get (w)->vertexBuffer()->end();
 }
 
 void
@@ -511,9 +501,7 @@ unity::TexGeometryCollection::setTexture (GLTexture *tex)
 
 void
 unity::TexGeometryCollection::addGeometriesAndDrawTextureForWindow(CompWindow *w,
-#ifdef USE_GLES
                                                                    const GLMatrix &transform,
-#endif
                                                                    unsigned int mask)
 {
   if (mTexture && mGeometries.status ())
@@ -524,47 +512,25 @@ unity::TexGeometryCollection::addGeometriesAndDrawTextureForWindow(CompWindow *w
     if (mask & PAINT_WINDOW_TRANSFORMED_MASK)
       paintRegion = infiniteRegion;
 
-    mGeometries.addGeometryForWindow (w, paintRegion);
-
-#ifdef USE_GLES
-    UnityDialogScreen *uds = UnityDialogScreen::get (screen);
-    GLWindowPaintAttrib attrib (gWindow->lastPaintAttrib());
-    unsigned int glDrawTextureIndex = gWindow->glDrawTextureGetCurrentIndex();
-    /* Texture rendering set-up */
-//    uds->gScreen->setTexEnvMode(GL_MODULATE);
-    glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-    /* Draw the dim texture with all of it's modified
-     * geometry glory */
-    gWindow->glDrawTextureSetCurrentIndex(MAXSHORT);
-    gWindow->glDrawTexture(mTexture, transform, attrib, mask
-					      | PAINT_WINDOW_BLEND_MASK
-					      | PAINT_WINDOW_TRANSLUCENT_MASK
-					      | PAINT_WINDOW_TRANSFORMED_MASK);
-    gWindow->glDrawTextureSetCurrentIndex(glDrawTextureIndex);
-    /* Texture rendering tear-down */
-    glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-    uds->gScreen->setTexEnvMode(GL_REPLACE);
-#else
-    if (gWindow->geometry().vertices)
+    if (mGeometries.addGeometryForWindow (w, paintRegion))
     {
-	UnityDialogScreen *uds = UnityDialogScreen::get (screen);
-	GLFragment::Attrib fa (gWindow->lastPaintAttrib());
-	unsigned int glDrawTextureIndex = gWindow->glDrawTextureGetCurrentIndex();
-	/* Texture rendering set-up */
-	uds->gScreen->setTexEnvMode(GL_MODULATE);
-	glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-	/* Draw the dim texture with all of it's modified
-	   * geometry glory */
-	gWindow->glDrawTextureSetCurrentIndex(MAXSHORT);
-	gWindow->glDrawTexture(mTexture, fa, mask | PAINT_WINDOW_BLEND_MASK
-			       | PAINT_WINDOW_TRANSLUCENT_MASK |
-			       PAINT_WINDOW_TRANSFORMED_MASK);
-	gWindow->glDrawTextureSetCurrentIndex(glDrawTextureIndex);
-	/* Texture rendering tear-down */
-	glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-	uds->gScreen->setTexEnvMode(GL_REPLACE);
+      UnityDialogScreen *uds = UnityDialogScreen::get (screen);
+      GLWindowPaintAttrib attrib (gWindow->lastPaintAttrib());
+      unsigned int glDrawTextureIndex = gWindow->glDrawTextureGetCurrentIndex();
+      /* Texture rendering set-up */
+      glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+      /* Draw the dim texture with all of it's modified
+       * geometry glory */
+      gWindow->glDrawTextureSetCurrentIndex(MAXSHORT);
+      gWindow->glDrawTexture(mTexture, transform, attrib, mask
+                                                | PAINT_WINDOW_BLEND_MASK
+                                                | PAINT_WINDOW_TRANSLUCENT_MASK
+                                                | PAINT_WINDOW_TRANSFORMED_MASK);
+      gWindow->glDrawTextureSetCurrentIndex(glDrawTextureIndex);
+      /* Texture rendering tear-down */
+      glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+      uds->gScreen->setTexEnvMode(GL_REPLACE);
     }
-#endif
   }
 }
 
@@ -619,17 +585,11 @@ unity::PaintInfoCollector::processTexture (GLTexture *tex)
 
 void
 unity::PaintInfoCollector::drawGeometriesForWindow(CompWindow *w,
-#ifdef USE_GLES
                                                    const GLMatrix &transform,
-#endif
                                                    unsigned int pm)
 {
   for (unity::TexGeometryCollection &tcg : mCollection)
-#if USE_GLES
     tcg.addGeometriesAndDrawTextureForWindow (w, transform, pm);
-#else
-    tcg.addGeometriesAndDrawTextureForWindow (w, pm);
-#endif
 }
 
 unity::PaintInfoCollector * unity::PaintInfoCollector::active_collector = NULL;
@@ -644,11 +604,7 @@ unity::PaintInfoCollector::Active ()
 
 bool
 UnityDialogWindow::glDraw(const GLMatrix& transform,
-#ifdef USE_GLES
                           const GLWindowPaintAttrib& attrib,
-#else
-                          GLFragment::Attrib& fragment,
-#endif
                           const CompRegion& region,
                           unsigned int mask)
 {
@@ -660,11 +616,7 @@ UnityDialogWindow::glDraw(const GLMatrix& transform,
   /* Draw the window on the bottom, we will be drawing the
    * dim render on top */
   bool status = gWindow->glDraw(transform,
-#ifdef USE_GLES
                                 attrib,
-#else
-                                fragment,
-#endif
                                 region, mask);
 
   UNITY_DIALOG_SCREEN(screen);
@@ -673,17 +625,11 @@ UnityDialogWindow::glDraw(const GLMatrix& transform,
   {
     GLTexture::MatrixList matl;
     GLTexture::Matrix     mat = tex->matrix();
-#ifdef USE_GLES
     GLWindowPaintAttrib   wAttrib(attrib);
-#endif
 
     /* We can reset the window geometry since it will be
      * re-added later */
-#ifdef USE_GLES
     gWindow->vertexBuffer()->begin();
-#else
-    gWindow->geometry().reset();
-#endif
 
     /* Scale the dim render by the ratio of dim size
      * to window size */
@@ -704,48 +650,25 @@ UnityDialogWindow::glDraw(const GLMatrix& transform,
      * dim (so we get a nice render for things like
      * wobbly etc etc */
     gWindow->glAddGeometry(matl, reg, paintRegion);
-#ifdef USE_GLES
-    gWindow->vertexBuffer()->end();
-#endif
-
-#ifdef USE_GLES
-    unsigned int glDrawTextureIndex = gWindow->glDrawTextureGetCurrentIndex();
-    wAttrib.opacity = mShadeProgress;
-    /* Texture rendering set-up */
-//    uds->gScreen->setTexEnvMode(GL_MODULATE);
-    glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-    /* Draw the dim texture with all of it's modified
-     * geometry glory */
-    gWindow->glDrawTextureSetCurrentIndex(MAXSHORT);
-    gWindow->glDrawTexture(tex, transform, attrib, mask
-                                              | PAINT_WINDOW_BLEND_MASK
-                                              | PAINT_WINDOW_TRANSLUCENT_MASK
-                                              | PAINT_WINDOW_TRANSFORMED_MASK);
-    gWindow->glDrawTextureSetCurrentIndex(glDrawTextureIndex);
-    /* Texture rendering tear-down */
-    glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-    uds->gScreen->setTexEnvMode(GL_REPLACE);
-#else
-    /* Did it succeed? */
-    if (gWindow->geometry().vertices)
+    if (gWindow->vertexBuffer()->end())
     {
       unsigned int glDrawTextureIndex = gWindow->glDrawTextureGetCurrentIndex();
-      fragment.setOpacity(mShadeProgress);
+      wAttrib.opacity = mShadeProgress;
       /* Texture rendering set-up */
-      uds->gScreen->setTexEnvMode(GL_MODULATE);
+      //    uds->gScreen->setTexEnvMode(GL_MODULATE);
       glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
       /* Draw the dim texture with all of it's modified
        * geometry glory */
       gWindow->glDrawTextureSetCurrentIndex(MAXSHORT);
-      gWindow->glDrawTexture(tex, fragment, mask | PAINT_WINDOW_BLEND_MASK
-                             | PAINT_WINDOW_TRANSLUCENT_MASK |
-                             PAINT_WINDOW_TRANSFORMED_MASK);
+      gWindow->glDrawTexture(tex, transform, attrib, mask
+                                                | PAINT_WINDOW_BLEND_MASK
+                                                | PAINT_WINDOW_TRANSLUCENT_MASK
+                                                | PAINT_WINDOW_TRANSFORMED_MASK);
       gWindow->glDrawTextureSetCurrentIndex(glDrawTextureIndex);
       /* Texture rendering tear-down */
       glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
       uds->gScreen->setTexEnvMode(GL_REPLACE);
     }
-#endif
   }
 
   for (CompWindow* w : mTransients)
@@ -759,9 +682,7 @@ UnityDialogWindow::glDraw(const GLMatrix& transform,
 
       pc.collect();
       pc.drawGeometriesForWindow (window,
-#ifdef USE_GLES
                                   transform,
-#endif
                                   mask);
     }
   }
@@ -1051,7 +972,7 @@ UnityDialogWindow::moveNotify(int dx, int dy, bool immediate)
   if (!mSkipNotify)
   {
     if (mParent && UnityDialogScreen::get(screen)->switchingVp() &&
-        !(mGrabMask && CompWindowGrabMoveMask))
+        !(mGrabMask & CompWindowGrabMoveMask))
     {
       moveParentToRect(window, window->serverBorderRect(), true);
     }
@@ -1383,7 +1304,6 @@ UnityDialogWindow::place(CompPoint& pos)
     CompWindow::Geometry transientGeometry;
     CompRegion transientPos, outputRegion, outsideArea, outsideRegion;
     pos = getChildCenteredPositionForRect(mParent->serverBorderRect());
-    int    hdirection, vdirection;
 
     transientGeometry = CompWindow::Geometry(pos.x(),
                                              pos.y(),
@@ -1406,8 +1326,8 @@ UnityDialogWindow::place(CompPoint& pos)
       int width;
       int height;
 
-      hdirection = outsideArea.boundingRect().x() < 0 ? 1 : -1;
-      vdirection = outsideArea.boundingRect().y() < 0 ? 1 : -1;
+      int hdirection = outsideArea.boundingRect().x() < 0 ? 1 : -1;
+      int vdirection = outsideArea.boundingRect().y() < 0 ? 1 : -1;
 
       width  = outsideArea.boundingRect().width() >=
                window->serverBorderRect().width() ? 0 :
