@@ -18,7 +18,6 @@
  */
 
 #include <gmock/gmock.h>
-#include "test_uscreen_mock.h"
 
 #include "FavoriteStore.h"
 #include "LauncherController.h"
@@ -33,8 +32,11 @@
 #include "SoftwareCenterLauncherIcon.h"
 #include "PanelStyle.h"
 #include "UnitySettings.h"
+#include "UBusMessages.h"
 #include "test_utils.h"
+#include "test_uscreen_mock.h"
 #include "test_mock_devices.h"
+#include "bamf-mock-application.h"
 
 using namespace unity::launcher;
 using namespace testing;
@@ -131,7 +133,7 @@ struct MockBamfLauncherIcon : public BamfLauncherIcon
   typedef bool Fake;
 
   MockBamfLauncherIcon(Fake = true, std::string const& remote_uri = "")
-    : BamfLauncherIcon(static_cast<BamfApplication*>(g_object_new(BAMF_TYPE_APPLICATION, nullptr)))
+    : BamfLauncherIcon(BAMF_APPLICATION(bamf_mock_application_new()))
     , remote_uri_(remote_uri)
   {
     InitMock();
@@ -203,6 +205,14 @@ struct TestLauncherController : public testing::Test
     lc.multiple_launchers = true;
   }
 
+  void ProcessUBusMessages()
+  {
+    bool expired = false;
+    glib::Idle idle([&] { expired = true; return false; },
+                    glib::Source::Priority::LOW);
+    Utils::WaitUntil(expired);
+  }
+
 protected:
   struct MockLauncherController : Controller
   {
@@ -1497,4 +1507,24 @@ TEST_F(TestLauncherController, UpdateNumWorkspacesEnable)
   EXPECT_TRUE(lc.Impl()->expo_icon_->IsVisible());
 }
 
+TEST_F(TestLauncherController, UpdateSelectionChanged)
+{
+  UBusManager manager;
+  std::string last_selection_change;
+  manager.RegisterInterest(UBUS_LAUNCHER_SELECTION_CHANGED, [&] (GVariant *data) { last_selection_change = g_variant_get_string(data, 0); });
+
+  lc.KeyNavGrab();
+  ProcessUBusMessages();
+  ASSERT_EQ(lc.Impl()->model_->Selection()->tooltip_text(), last_selection_change);
+
+  lc.KeyNavNext();
+  ProcessUBusMessages();
+  ASSERT_EQ(lc.Impl()->model_->Selection()->tooltip_text(), last_selection_change);
+
+  lc.Impl()->OpenQuicklist();
+  lc.Impl()->model_->Selection()->CloseQuicklist();
+  ProcessUBusMessages();
+  ASSERT_EQ(lc.Impl()->model_->Selection()->tooltip_text(), last_selection_change);
+}
+
 }
