@@ -8,6 +8,7 @@ static void add_categories(ServiceLens* self);
 static void add_filters(ServiceLens *self);
 static void on_search_changed(UnityScope* scope, UnityLensSearch *lens_search, UnitySearchType search_type, GCancellable *canc, ServiceLens* self);
 static UnityActivationResponse* on_activate_uri(UnityScope* scope, const char* uri, ServiceLens* self);
+static UnityPreview* on_preview_uri(UnityScope* scope, const char* uri, ServiceLens *self);
 
 struct _ServiceLensPrivate
 {
@@ -58,6 +59,8 @@ service_lens_init(ServiceLens* self)
                    G_CALLBACK(on_search_changed), self);
   g_signal_connect(priv->scope, "activate-uri",
                    G_CALLBACK(on_activate_uri), self);
+  g_signal_connect(priv->scope, "preview-uri",
+                   G_CALLBACK(on_preview_uri), self);
 
   /* Get ready to export and export */
   unity_lens_add_local_scope(priv->lens, priv->scope);
@@ -171,7 +174,7 @@ on_search_changed(UnityScope* scope, UnityLensSearch *search,
     g_free(name);
   }
 
-  g_signal_emit_by_name (search, "finished");
+  unity_lens_search_finished (search);
 }
 
 static UnityActivationResponse*
@@ -180,6 +183,29 @@ on_activate_uri(UnityScope* scope, const char* uri, ServiceLens* self)
   return unity_activation_response_new(UNITY_HANDLED_TYPE_HIDE_DASH, "");
 }
 
+static UnityActivationResponse*
+preview_action_activated(UnityPreviewAction* action, const char* uri)
+{
+  return unity_activation_response_new(UNITY_HANDLED_TYPE_SHOW_DASH, "");
+}
+
+static UnityPreview*
+on_preview_uri(UnityScope* scope, const char* uri, ServiceLens *self)
+{
+  UnityPreviewAction* action;
+  UnityMoviePreview* preview;
+
+  preview = unity_movie_preview_new("A movie", "With subtitle",
+                                    "And description", NULL);
+
+  action = unity_preview_action_new("action_A", "An action", NULL);
+  unity_preview_add_action(UNITY_PREVIEW(preview), action);
+  g_signal_connect(action, "activated",
+                   G_CALLBACK(preview_action_activated), NULL);
+
+  return (UnityPreview*) preview;
+}
+
 ServiceLens*
 service_lens_new()
 {
